@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: descriptive
 version: 0.9.4
-id: descriptive-0.9.4-0d64036b714063685e6c8fe815c24d1f
-key: descr_GlF7zdcyLeR16ooQ79t856
+id: descriptive-0.9.4-5b20db39d8b82847194f317f7419d9b2
+key: descr_LyCkz3iKhnrJIfMKuJz2ai
 license: BSD3
 copyright: 2015 Chris Done
 maintainer: chrisdone@gmail.com
@@ -23,14 +23,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/descriptive-0.9.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/descriptive-0.9.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/descriptive-0.9.4
-hs-libraries: HSdescriptive-0.9.4-GlF7zdcyLeR16ooQ79t856
+hs-libraries: HSdescriptive-0.9.4-LyCkz3iKhnrJIfMKuJz2ai
 depends:
-    aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
+    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bifunctors-5.2.1-854727fccb4481ffefcc20f535d6c50b
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
+    scientific-0.3.4.6-460bb668ffbf15e21b1a22bd826e372c
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
